As pointed out by Gary on the Poky ML, packaging takes an extremely long time: "Here's what I mean. Building for my kernel and timing the various steps, e.g. % time bitbake virtual/kernel -c compile My kernel: compile 1m49s deploy 0m16s populate_sysroot 0m38s package 23m20s" https://lists.yoctoproject.org/pipermail/poky/2011-January/002635.html This performance impact may have been introduced by recent changes to the package.bbclass to use the rpmdeps command to discover per-file dependencies. http://git.yoctoproject.org/cgit/cgit.cgi/poky/commit/?id=54e3a82d9c14f3071db4a4f78312c0e31534696c
A second theory is that the bitbake package/server split is causing a lot of context switches for the messages, during package creation - particularly for large packages like the the kernel. See: https://lists.yoctoproject.org/pipermail/poky/2011-January/002638.html
This was traced to the server end of the worker communication pipe using small buffers. We've increased the size of the pipe and performance improved dramatically.
Verify fixed